from mahabharata.models import MahabharataPoems


POEMS = MahabharataPoems.parse_obj(
    [
        {
            "quote": "Time creates all things and time destroys them all. Time burns all creatures and time again extinguishes that fire",
            "authors": "Anukramanika Parva, Adi Parva",
        },
        {
            "quote": "What is a greater happiness to a father than what the father feels when his son, running to him, clasps him with his tiny little arms, though his body is full of dust and dirt.",
            "authors": "Sambhava Parva, Adi Parva",
        },
        {
            "quote": "Friendship never remains in the world in anyone’s heart without being worn out, Time wears it out, anger destroys it. The poor cannot be the friend of the rich, the unlearned cannot be the friend of the learned, the coward cannot be the friend of the brave.",
            "authors": "Drupada to Drona, Sambhava Parva, Adi Parva",
        },
        {
            "quote": "Men of immature understanding begin an act without having an eye to what may happen in future.",
            "authors": "Rajshuyarambha Parva, Sabha Parva",
        },
        {
            "quote": "Whatever actions are performed by a man under whatever circumstances, he gets the fruits of those actions under whatever circumstances they may be performed.",
            "authors": "Krishna, Jarasandhabadha Parva Sabha Parva",
        },
        {
            "quote": "Men experience happiness and misery by turn. No man ever enjoys unmixed happiness. A wise man, possessing high wisdom, knowing that life has its ups and downs, is neither filled with joy nor with grief. When happiness comes, one should enjoy it, and when misery comes one should bear it",
            "authors": "Vrihi Drounika Parva, Aranya Parva",
        },
        {
            "quote": "Pleasant looks, cheerful heart and sweet words are due to a guest. Rising up, the host should advance towards the guest; he should offer him a seat, and duly worship him. This is the eternal Dharma.",
            "authors": "Aranyaka Parva, Aranya Parva",
        },
        {
            "quote": "Anger is in this world, the root of the destruction of mankind, The angry man commits a sin; the angry man murders his preceptor; the angry man insults his ciders with harsh words. The angry man cannot distinguish what should be and should not be said by him. there is nothing which cannot be said or done by an angry man.",
            "authors": "Yudhishthira, Arjunabhigamana Parva, Aranya Parva",
        },
        {
            "quote": "A wise man should never contract friendship with the wife of the king nor with other attendants of his, nor with those whom he despises and who are hostile to him.",
            "authors": "Pandava Pravesha Parva, Virata Parva",
        },
    ]
)
